# Configuring SCIM in Okta
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-scim-in-okta#prerequisites)
  * [Configuring User Provisioning](https://help.sap.com/docs/leanix/ea/configuring-scim-in-okta#configuring-user-provisioning)


Instructions for configuring SCIM provisioning in Okta. SCIM allows you to enable seamless and automated user management across your applications.
